@@ -1,3 +1,5 @@
+#![ warn( missing_docs ) ]
+#![ warn( missing_debug_implementations ) ]
 
 ///
 /// Macro asserts that two expressions are identical to each other. Unlike std::assert_eq it is removed from a release build.
